==> nextcloud-27.1.11.tgz: nextcloud/apps/twofactor_backupcodes/l10n/ja.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "アカウントの二要素認証バックアップコードを作成しました",
    "Second-factor backup codes" : "第二要素バックアップコード",
    "Generate backup codes" : "バックアップコードを生成",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "二要素認証を有効にしましたが、まだバックアップコードを生成していません。 2番めの要素を失った際、アカウントへのアクセスを回復するために必要とされます。",
    "Backup code" : "バックアップコード",
    "Use backup code" : "バックアップコードを使用する",
    "Two factor backup codes" : "二要素認証バックアップコード",
    "A two-factor auth backup codes provider" : "二要素認証バックアップコードプロバイダー",
    "Backup codes have been generated. {used} of {total} codes have been used." : "バックアップコードが生成されました。 {total} 個のうち {used} 個のコードが使用されています。",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "以下はあなたのバックアップコードです。 後からこのコードを見ることはできないので、保存するか印刷しておいてください",
    "Save backup codes" : "バックアップコードを保存",
    "Print backup codes" : "バックアップコードを印刷",
    "Regenerate backup codes" : "バックアップコードを再生成",
    "If you regenerate backup codes, you automatically invalidate old codes." : "バックアップコードを再生成すると、自動的に古いコードが無効になります。",
    "An error occurred while generating your backup codes" : "バックアップコードの生成中にエラーが発生しました",
    "{name} backup codes" : "{name} バックアップコード",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "二要素認証を設定するときに保存したバックアップコードのいずれかを使用します。",
    "Submit" : "了解"
},
"nplurals=1; plural=0;");

==> nextcloud-30.0.10.tgz: nextcloud/apps/twofactor_backupcodes/l10n/ja.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "アカウントの二要素認証バックアップコードを作成しました",
    "Second-factor backup codes" : "第二要素バックアップコード",
    "Generate backup codes" : "バックアップコードを生成",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "二要素認証を有効にしましたが、まだバックアップコードを生成していません。 2番めの要素を失った際、アカウントへのアクセスを回復するために必要とされます。",
    "Backup code" : "バックアップコード",
    "Use backup code" : "バックアップコードを使用する",
    "Two factor backup codes" : "二要素認証バックアップコード",
    "A two-factor auth backup codes provider" : "二要素認証バックアップコードプロバイダー",
    "An error occurred while generating your backup codes" : "バックアップコードの生成中にエラーが発生しました",
    "Backup codes have been generated. {used} of {total} codes have been used." : "バックアップコードが生成されました。 {total} 個のうち {used} 個のコードが使用されています。",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later." : "これらはバックアップコードです。後でコードを再度読み取ることはできませんので、保存または印刷してください。",
    "Save backup codes" : "バックアップコードを保存",
    "Print backup codes" : "バックアップコードを印刷",
    "Regenerate backup codes" : "バックアップコードを再生成",
    "If you regenerate backup codes, you automatically invalidate old codes." : "バックアップコードを再生成すると、自動的に古いコードが無効になります。",
    "{name} backup codes" : "{name} バックアップコード",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "二要素認証を設定するときに保存したバックアップコードのいずれかを使用します。",
    "Submit" : "了解",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "以下はあなたのバックアップコードです。 後からこのコードを見ることはできないので、保存するか印刷しておいてください"
},
"nplurals=1; plural=0;");
